*****
Flows
*****

.. automodule:: networkx.algorithms.flow
.. currentmodule:: networkx

Ford-Fulkerson
--------------
.. autosummary::
   :toctree: generated/

   max_flow
   min_cut
   ford_fulkerson
